==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/BastionShareableLink.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.BastionShareableLink.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Bastion Shareable Link.
 * @property vm Reference of the virtual machine resource.
 */
public data class BastionShareableLink(
    public val vm: VM,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.BastionShareableLink> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.BastionShareableLink =
        com.pulumi.azurenative.network.inputs.BastionShareableLink.builder()
            .vm(vm.let({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [BastionShareableLink].
 */
@PulumiTagMarker
public class BastionShareableLinkBuilder internal constructor() {
    private var vm: VM? = null

    /**
     * @param value Reference of the virtual machine resource.
     */
    @JvmName("hjuxrgqxcdlmrlcv")
    public suspend fun vm(`value`: VM) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.vm = mapped
    }

    /**
     * @param argument Reference of the virtual machine resource.
     */
    @JvmName("etmbrjdfbeuvngmv")
    public suspend fun vm(argument: suspend VMBuilder.() -> Unit) {
        val toBeMapped = VMBuilder().applySuspend { argument() }.build()
        val mapped = toBeMapped
        this.vm = mapped
    }

    internal fun build(): BastionShareableLink = BastionShareableLink(
        vm = vm ?: throw PulumiNullFieldException("vm"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/BastionShareableLink.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.BastionShareableLink.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Bastion Shareable Link.
 * @property vm Reference of the virtual machine resource.
 */
public data class BastionShareableLink(
    public val vm: VM,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.BastionShareableLink> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.BastionShareableLink =
        com.pulumi.azurenative.network.inputs.BastionShareableLink.builder()
            .vm(vm.let({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [BastionShareableLink].
 */
@PulumiTagMarker
public class BastionShareableLinkBuilder internal constructor() {
    private var vm: VM? = null

    /**
     * @param value Reference of the virtual machine resource.
     */
    @JvmName("swjmjwcchrlpmoow")
    public suspend fun vm(`value`: VM) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.vm = mapped
    }

    /**
     * @param argument Reference of the virtual machine resource.
     */
    @JvmName("pkmkhhfpumokcyru")
    public suspend fun vm(argument: suspend VMBuilder.() -> Unit) {
        val toBeMapped = VMBuilder().applySuspend { argument() }.build()
        val mapped = toBeMapped
        this.vm = mapped
    }

    internal fun build(): BastionShareableLink = BastionShareableLink(
        vm = vm ?: throw PulumiNullFieldException("vm"),
    )
}
